==> libsndfile_1.0.31.orig.tar.gz: libsndfile-1.0.31/src/config.h.cmake <==
/* Set to 1 if the compile is GNU GCC. */
#cmakedefine01 COMPILER_IS_GCC

/* Target processor clips on negative float to int conversion. */
#cmakedefine01 CPU_CLIPS_NEGATIVE

/* Target processor clips on positive float to int conversion. */
#cmakedefine01 CPU_CLIPS_POSITIVE

/* Target processor is big endian. */
#cmakedefine01 CPU_IS_BIG_ENDIAN

/* Target processor is little endian. */
#cmakedefine01 CPU_IS_LITTLE_ENDIAN

/* Set to 1 to enable experimental code. */
#cmakedefine01 ENABLE_EXPERIMENTAL_CODE

/* Define to 1 if you have the <alsa/asoundlib.h> header file. */
#cmakedefine01 HAVE_ALSA_ASOUNDLIB_H

/* Define to 1 if you have the <byteswap.h> header file. */
#cmakedefine01 HAVE_BYTESWAP_H

/* Define to 1 if you have the `calloc' function. */
#cmakedefine01 HAVE_CALLOC

/* Define to 1 if you have the `ceil' function. */
#cmakedefine01 HAVE_CEIL

/* Set to 1 if S_IRGRP is defined. */
#cmakedefine01 HAVE_DECL_S_IRGRP

/* Define to 1 if you have the <dlfcn.h> header file. */
#cmakedefine01 HAVE_DLFCN_H

/* Define to 1 if you have the <direct.h> header file. */
#cmakedefine HAVE_DIRECT_H

/* Define to 1 if you have the <endian.h> header file. */
#cmakedefine01 HAVE_ENDIAN_H

/* Will be set to 1 if flac, ogg and vorbis are available. */
#cmakedefine01 HAVE_EXTERNAL_XIPH_LIBS

/* Define to 1 if you have the `floor' function. */
#cmakedefine01 HAVE_FLOOR

/* Define to 1 if you have the `fmod' function. */
#cmakedefine01 HAVE_FMOD

/* Define to 1 if you have the `free' function. */
#cmakedefine01 HAVE_FREE

/* Define to 1 if you have the `fstat' function. */
#cmakedefine01 HAVE_FSTAT

/* Define to 1 if you have the `fstat64' function. */
#cmakedefine01 HAVE_FSTAT64

/* Define to 1 if you have the `fsync' function. */
#cmakedefine01 HAVE_FSYNC

/* Define to 1 if you have the `ftruncate' function. */
#cmakedefine01 HAVE_FTRUNCATE

/* Define to 1 if you have the `getpagesize' function. */
#cmakedefine01 HAVE_GETPAGESIZE

/* Define to 1 if you have the `gettimeofday' function. */
#cmakedefine01 HAVE_GETTIMEOFDAY

/* Define if you have the `gmtime' function. */
#cmakedefine HAVE_GMTIME

/* Define if you have the `gmtime_r' function. */
#cmakedefine HAVE_GMTIME_R

/* Define to 1 if you have the <inttypes.h> header file. */
#cmakedefine01 HAVE_INTTYPES_H

/* Define to 1 if you have the <io.h> header file. */
#cmakedefine HAVE_IO_H

/* Define to 1 if you have the `m' library (-lm). */
#cmakedefine01 HAVE_LIBM

/* Define to 1 if you have the <locale.h> header file. */
#cmakedefine01 HAVE_LOCALE_H

/* Define if you have the `localtime' function. */
#cmakedefine HAVE_LOCALTIME

/* Define if you have the `localtime_r' function. */
#cmakedefine HAVE_LOCALTIME_R

/* Define if you have C99's lrint function. */
#cmakedefine01 HAVE_LRINT

/* Define if you have C99's lrintf function. */
#cmakedefine01 HAVE_LRINTF

/* Define to 1 if you have the `lround' function. */
#cmakedefine01 HAVE_LROUND

/* Define to 1 if you have the `lseek' function. */
#cmakedefine01 HAVE_LSEEK

/* Define to 1 if you have the `lseek64' function. */
#cmakedefine01 HAVE_LSEEK64

/* Define to 1 if you have the `malloc' function. */
#cmakedefine01 HAVE_MALLOC

/* Define to 1 if you have the <memory.h> header file. */
#cmakedefine01 HAVE_MEMORY_H

/* Define to 1 if you have the `mmap' function. */
#cmakedefine01 HAVE_MMAP

/* Define to 1 if you have the `open' function. */
#cmakedefine01 HAVE_OPEN

/* Define to 1 if you have the `pipe' function. */
#cmakedefine01 HAVE_PIPE

/* Define to 1 if you have the `read' function. */
#cmakedefine01 HAVE_READ

/* Define to 1 if you have the `realloc' function. */
#cmakedefine01 HAVE_REALLOC

/* Define to 1 if you have the `setlocale' function. */
#cmakedefine01 HAVE_SETLOCALE

/* Set to 1 if <sndio.h> is available. */
#cmakedefine01 HAVE_SNDIO_H

/* Define to 1 if you have the `snprintf' function. */
#cmakedefine01 HAVE_SNPRINTF

/* Set to 1 if you have libsqlite3. */
#cmakedefine01 HAVE_SQLITE3

/* Define to 1 if the system has the type `ssize_t'. */
#cmakedefine01 HAVE_SSIZE_T

/* Define to 1 if you have the <stdint.h> header file. */
#cmakedefine01 HAVE_STDINT_H

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine01 HAVE_STDLIB_H

/* Define to 1 if you have the <strings.h> header file. */
#cmakedefine01 HAVE_STRINGS_H

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine01 HAVE_STRING_H

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine01 HAVE_SYS_STAT_H

/* Define to 1 if you have the <sys/time.h> header file. */
#cmakedefine01 HAVE_SYS_TIME_H

/* Define to 1 if you have the <sys/types.h> header file. */
#cmakedefine01 HAVE_SYS_TYPES_H

/* Define to 1 if you have <sys/wait.h> that is POSIX.1 compatible. */
#cmakedefine01 HAVE_SYS_WAIT_H

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine01 HAVE_UNISTD_H

/* Define to 1 if you have the <immintrin.h> header file. */
#cmakedefine01 HAVE_IMMINTRIN_H

/* Define to 1 if you have the `vsnprintf' function. */
#cmakedefine01 HAVE_VSNPRINTF

/* Define to 1 if you have the `waitpid' function. */
#cmakedefine01 HAVE_WAITPID

/* Define to 1 if you have the `write' function. */
#cmakedefine01 HAVE_WRITE

/* The darwin version, no-zero is valid */
#cmakedefine01 OSX_DARWIN_VERSION

/* Set to 1 if compiling for OpenBSD */
#cmakedefine01 OS_IS_OPENBSD

/* Set to 1 if compiling for Win32 */
#cmakedefine01 OS_IS_WIN32

/* Set to 1 if SSE2 is enabled */
#cmakedefine USE_SSE2

/* Name of package */
#define PACKAGE "@PACKAGE_NAME@"

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "@PACKAGE_BUGREPORT@"

/* Define to the full name of this package. */
#define PACKAGE_NAME "@PACKAGE_NAME@"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "@PACKAGE_NAME@ @CPACK_PACKAGE_VERSION_FULL@"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "@PACKAGE_NAME@"

/* Define to the home page for this package. */
#define PACKAGE_URL "@PACKAGE_URL@"

/* Define to the version of this package. */
#define PACKAGE_VERSION "@CPACK_PACKAGE_VERSION_FULL@"

/* Set to maximum allowed value of sf_count_t type. */
#define SF_COUNT_MAX @SF_COUNT_MAX@

/* The size of `double', as computed by sizeof. */
@SIZEOF_DOUBLE_CODE@

/* The size of `float', as computed by sizeof. */
@SIZEOF_FLOAT_CODE@

/* The size of `int', as computed by sizeof. */
@SIZEOF_INT_CODE@

/* The size of `int64_t', as computed by sizeof. */
@SIZEOF_INT64_T_CODE@

/* The size of `loff_t', as computed by sizeof. */
@SIZEOF_LOFF_T_CODE@

/* The size of `long', as computed by sizeof. */
@SIZEOF_LONG_CODE@

/* The size of `long long', as computed by sizeof. */
@SIZEOF_LONG_LONG_CODE@

/* The size of `off64_t', as computed by sizeof. */
@SIZEOF_OFF64_T_CODE@

/* The size of `off_t', as computed by sizeof. */
@SIZEOF_OFF_T_CODE@

/* Set to sizeof (long) if unknown. */
@SIZEOF_SF_COUNT_T_CODE@

/* The size of `short', as computed by sizeof. */
@SIZEOF_SHORT_CODE@

/* The size of `size_t', as computed by sizeof. */
@SIZEOF_SIZE_T_CODE@

/* The size of `ssize_t', as computed by sizeof. */
@SIZEOF_SSIZE_T_CODE@

/* The size of `void*', as computed by sizeof. */
@SIZEOF_VOIDP_CODE@

/* The size of `wchar_t', as computed by sizeof. */
@SIZEOF_WCHAR_T_CODE@

/* Set to long if unknown. */
#define TYPEOF_SF_COUNT_T @TYPEOF_SF_COUNT_T@

/* Enable extensions on AIX 3, Interix.  */
#ifndef _ALL_SOURCE
# undef _ALL_SOURCE
#endif
/* Enable GNU extensions on systems that have them.  */
#ifndef _GNU_SOURCE
# undef _GNU_SOURCE
#endif
/* Enable threading extensions on Solaris.  */
#ifndef _POSIX_PTHREAD_SEMANTICS
# undef _POSIX_PTHREAD_SEMANTICS
#endif
/* Enable extensions on HP NonStop.  */
#ifndef _TANDEM_SOURCE
# undef _TANDEM_SOURCE
#endif
/* Enable general extensions on Solaris.  */
#ifndef __EXTENSIONS__
# undef __EXTENSIONS__
#endif


/* Set to 1 to use the native windows API */
#cmakedefine01 USE_WINDOWS_API

/* Version number of package */
#define VERSION "@PROJECT_VERSION@"

/* Set to 1 if windows DLL is being built. */
#cmakedefine01 WIN32_TARGET_DLL

/* Target processor is big endian. */
#cmakedefine01 WORDS_BIGENDIAN

/* Enable large inode numbers on Mac OS X 10.5.  */
#ifndef _DARWIN_USE_64_BIT_INODE
# define _DARWIN_USE_64_BIT_INODE 1
#endif

/* Define to 1 if on MINIX. */
#cmakedefine01 _MINIX

/* Define as `__inline' or '__inline__' if that's what the C compiler calls it, or to nothing if it is not supported. */
@INLINE_CODE@

==> libsndfile_1.2.0.orig.tar.gz: libsndfile-1.2.0/src/config.h.cmake <==
/* Set to 1 if the compile is GNU GCC. */
#cmakedefine01 COMPILER_IS_GCC

/* Target processor clips on negative float to int conversion. */
#cmakedefine01 CPU_CLIPS_NEGATIVE

/* Target processor clips on positive float to int conversion. */
#cmakedefine01 CPU_CLIPS_POSITIVE

/* Target processor is big endian. */
#cmakedefine01 CPU_IS_BIG_ENDIAN

/* Target processor is little endian. */
#cmakedefine01 CPU_IS_LITTLE_ENDIAN

/* Set to 1 to enable experimental code. */
#cmakedefine01 ENABLE_EXPERIMENTAL_CODE

/* Define to 1 if you have the <alsa/asoundlib.h> header file. */
#cmakedefine01 HAVE_ALSA_ASOUNDLIB_H

/* Define to 1 if you have the <byteswap.h> header file. */
#cmakedefine01 HAVE_BYTESWAP_H

/* Define to 1 if you have the `calloc' function. */
#cmakedefine01 HAVE_CALLOC

/* Define to 1 if you have the `ceil' function. */
#cmakedefine01 HAVE_CEIL

/* Set to 1 if S_IRGRP is defined. */
#cmakedefine01 HAVE_DECL_S_IRGRP

/* Define to 1 if you have the <dlfcn.h> header file. */
#cmakedefine01 HAVE_DLFCN_H

/* Define to 1 if you have the <direct.h> header file. */
#cmakedefine HAVE_DIRECT_H

/* Define to 1 if you have the <endian.h> header file. */
#cmakedefine01 HAVE_ENDIAN_H

/* Will be set to 1 if flac, ogg and vorbis are available. */
#cmakedefine01 HAVE_EXTERNAL_XIPH_LIBS

/* Will be set to 1 if lame and mpg123 are available. */
#cmakedefine01 HAVE_MPEG

/* Define to 1 if you have the `floor' function. */
#cmakedefine01 HAVE_FLOOR

/* Define to 1 if you have the `fmod' function. */
#cmakedefine01 HAVE_FMOD

/* Define to 1 if you have the `free' function. */
#cmakedefine01 HAVE_FREE

/* Define to 1 if you have the `fstat' function. */
#cmakedefine01 HAVE_FSTAT

/* Define to 1 if you have the `fstat64' function. */
#cmakedefine01 HAVE_FSTAT64

/* Define to 1 if you have the `fsync' function. */
#cmakedefine01 HAVE_FSYNC

/* Define to 1 if you have the `ftruncate' function. */
#cmakedefine01 HAVE_FTRUNCATE

/* Define to 1 if you have the `getpagesize' function. */
#cmakedefine01 HAVE_GETPAGESIZE

/* Define to 1 if you have the `gettimeofday' function. */
#cmakedefine01 HAVE_GETTIMEOFDAY

/* Define if you have the `gmtime' function. */
#cmakedefine HAVE_GMTIME

/* Define if you have the `gmtime_r' function. */
#cmakedefine HAVE_GMTIME_R

/* Define to 1 if you have the <inttypes.h> header file. */
#cmakedefine01 HAVE_INTTYPES_H

/* Define to 1 if you have the <io.h> header file. */
#cmakedefine HAVE_IO_H

/* Define to 1 if you have the `m' library (-lm). */
#cmakedefine01 HAVE_LIBM

/* Define to 1 if you have the <locale.h> header file. */
#cmakedefine01 HAVE_LOCALE_H

/* Define if you have the `localtime' function. */
#cmakedefine HAVE_LOCALTIME

/* Define if you have the `localtime_r' function. */
#cmakedefine HAVE_LOCALTIME_R

/* Define if you have C99's lrint function. */
#cmakedefine01 HAVE_LRINT

/* Define if you have C99's lrintf function. */
#cmakedefine01 HAVE_LRINTF

/* Define to 1 if you have the `lround' function. */
#cmakedefine01 HAVE_LROUND

/* Define to 1 if you have the `lseek' function. */
#cmakedefine01 HAVE_LSEEK

/* Define to 1 if you have the `lseek64' function. */
#cmakedefine01 HAVE_LSEEK64

/* Define to 1 if you have the `malloc' function. */
#cmakedefine01 HAVE_MALLOC

/* Define to 1 if you have the <memory.h> header file. */
#cmakedefine01 HAVE_MEMORY_H

/* Define to 1 if you have the `mmap' function. */
#cmakedefine01 HAVE_MMAP

/* Define to 1 if you have the `open' function. */
#cmakedefine01 HAVE_OPEN

/* Define to 1 if you have the `pipe' function. */
#cmakedefine01 HAVE_PIPE

/* Define to 1 if you have the `read' function. */
#cmakedefine01 HAVE_READ

/* Define to 1 if you have the `realloc' function. */
#cmakedefine01 HAVE_REALLOC

/* Define to 1 if you have the `setlocale' function. */
#cmakedefine01 HAVE_SETLOCALE

/* Set to 1 if <sndio.h> is available. */
#cmakedefine01 HAVE_SNDIO_H

/* Define to 1 if you have the `snprintf' function. */
#cmakedefine01 HAVE_SNPRINTF

/* Set to 1 if you have libsqlite3. */
#cmakedefine01 HAVE_SQLITE3

/* Define to 1 if the system has the type `ssize_t'. */
#cmakedefine01 HAVE_SSIZE_T

/* Define to 1 if you have the <stdint.h> header file. */
#cmakedefine01 HAVE_STDINT_H

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine01 HAVE_STDLIB_H

/* Define to 1 if you have the <strings.h> header file. */
#cmakedefine01 HAVE_STRINGS_H

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine01 HAVE_STRING_H

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine01 HAVE_SYS_STAT_H

/* Define to 1 if you have the <sys/time.h> header file. */
#cmakedefine01 HAVE_SYS_TIME_H

/* Define to 1 if you have the <sys/types.h> header file. */
#cmakedefine01 HAVE_SYS_TYPES_H

/* Define to 1 if you have <sys/wait.h> that is POSIX.1 compatible. */
#cmakedefine01 HAVE_SYS_WAIT_H

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine01 HAVE_UNISTD_H

/* Define to 1 if you have the <immintrin.h> header file. */
#cmakedefine01 HAVE_IMMINTRIN_H

/* Define to 1 if you have the <stdbool.h> header file. */
#cmakedefine01 HAVE_STDBOOL_H

/* Define to 1 if you have the `vsnprintf' function. */
#cmakedefine01 HAVE_VSNPRINTF

/* Define to 1 if you have the `waitpid' function. */
#cmakedefine01 HAVE_WAITPID

/* Define to 1 if you have the `write' function. */
#cmakedefine01 HAVE_WRITE

/* The darwin version, no-zero is valid */
#cmakedefine01 OSX_DARWIN_VERSION

/* Set to 1 if compiling for OpenBSD */
#cmakedefine01 OS_IS_OPENBSD

/* Set to 1 if compiling for Win32 */
#cmakedefine01 OS_IS_WIN32

/* Set to 1 if SSE2 is enabled */
#cmakedefine USE_SSE2

/* Name of package */
#define PACKAGE "@PACKAGE_NAME@"

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "@PACKAGE_BUGREPORT@"

/* Define to the full name of this package. */
#define PACKAGE_NAME "@PACKAGE_NAME@"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "@PACKAGE_NAME@ @CPACK_PACKAGE_VERSION_FULL@"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "@PACKAGE_NAME@"

/* Define to the home page for this package. */
#define PACKAGE_URL "@PACKAGE_URL@"

/* Define to the version of this package. */
#define PACKAGE_VERSION "@CPACK_PACKAGE_VERSION_FULL@"

/* The size of `double', as computed by sizeof. */
@SIZEOF_DOUBLE_CODE@

/* The size of `float', as computed by sizeof. */
@SIZEOF_FLOAT_CODE@

/* The size of `int', as computed by sizeof. */
@SIZEOF_INT_CODE@

/* The size of `int64_t', as computed by sizeof. */
@SIZEOF_INT64_T_CODE@

/* The size of `loff_t', as computed by sizeof. */
@SIZEOF_LOFF_T_CODE@

/* The size of `long', as computed by sizeof. */
@SIZEOF_LONG_CODE@

/* The size of `long long', as computed by sizeof. */
@SIZEOF_LONG_LONG_CODE@

/* The size of `off64_t', as computed by sizeof. */
@SIZEOF_OFF64_T_CODE@

/* The size of `off_t', as computed by sizeof. */
@SIZEOF_OFF_T_CODE@

/* The size of `short', as computed by sizeof. */
@SIZEOF_SHORT_CODE@

/* The size of `size_t', as computed by sizeof. */
@SIZEOF_SIZE_T_CODE@

/* The size of `ssize_t', as computed by sizeof. */
@SIZEOF_SSIZE_T_CODE@

/* The size of `void*', as computed by sizeof. */
@SIZEOF_VOIDP_CODE@

/* The size of `wchar_t', as computed by sizeof. */
@SIZEOF_WCHAR_T_CODE@

/* Enable extensions on AIX 3, Interix.  */
#ifndef _ALL_SOURCE
# undef _ALL_SOURCE
#endif
/* Enable GNU extensions on systems that have them.  */
#ifndef _GNU_SOURCE
# undef _GNU_SOURCE
#endif
/* Enable threading extensions on Solaris.  */
#ifndef _POSIX_PTHREAD_SEMANTICS
# undef _POSIX_PTHREAD_SEMANTICS
#endif
/* Enable extensions on HP NonStop.  */
#ifndef _TANDEM_SOURCE
# undef _TANDEM_SOURCE
#endif
/* Enable general extensions on Solaris.  */
#ifndef __EXTENSIONS__
# undef __EXTENSIONS__
#endif


/* Set to 1 to use the native windows API */
#cmakedefine01 USE_WINDOWS_API

/* Version number of package */
#define VERSION "@PROJECT_VERSION@"

/* Set to 1 if windows DLL is being built. */
#cmakedefine01 WIN32_TARGET_DLL

/* Target processor is big endian. */
#cmakedefine01 WORDS_BIGENDIAN

/* Enable large inode numbers on Mac OS X 10.5.  */
#ifndef _DARWIN_USE_64_BIT_INODE
# define _DARWIN_USE_64_BIT_INODE 1
#endif

/* Define to 1 if on MINIX. */
#cmakedefine01 _MINIX

/* Define as `__inline' or '__inline__' if that's what the C compiler calls it, or to nothing if it is not supported. */
@INLINE_CODE@
